"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var apollo_link_1 = require("apollo-link");
var graphql_1 = require("graphql");
var reactive_graphql_1 = require("reactive-graphql");
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
// will transform the errors of the execution results provided by
// reactive-graphql in proper GraphQLErrors
function normalizeErrorsField(results) {
    var _results = {};
    _results.data = results.data;
    if (results.errors) {
        _results.errors = results.errors.map(function (message) {
            // @ts-ignore just to be sure, message could be an instance of error
            if (typeof message.message === 'string') {
                // @ts-ignore 
                return new graphql_1.GraphQLError(message.message);
            }
            return new graphql_1.GraphQLError(message);
        });
    }
    return _results;
}
var ReactiveSchemaLink = /** @class */ (function (_super) {
    __extends(ReactiveSchemaLink, _super);
    function ReactiveSchemaLink(_a) {
        var schema = _a.schema, context = _a.context;
        var _this = _super.call(this) || this;
        _this.schema = schema;
        _this.context = context;
        return _this;
    }
    ReactiveSchemaLink.prototype.request = function (operation) {
        var _this = this;
        return new apollo_link_1.Observable(function (observer) {
            try {
                var context = typeof _this.context === 'function' ? _this.context(operation) : _this.context || {};
                return reactive_graphql_1.graphql(_this.schema, operation.query, null, context, operation.variables)
                    // reactive-graphql does not necessarely leverage the errors key (https://github.com/mesosphere/reactive-graphql/issues/13)
                    // so we do it ourself
                    .pipe(operators_1.catchError(function (error) { return rxjs_1.of({ errors: [new graphql_1.GraphQLError(error.message)] }); }))
                    .pipe(operators_1.map(normalizeErrorsField))
                    .subscribe(observer);
            }
            catch (e) {
                if (e instanceof Error) {
                    observer.next({ errors: [new graphql_1.GraphQLError(e.message)] });
                }
                else
                    throw e;
            }
        });
    };
    return ReactiveSchemaLink;
}(apollo_link_1.ApolloLink));
exports.ReactiveSchemaLink = ReactiveSchemaLink;
exports.default = ReactiveSchemaLink;
//# sourceMappingURL=reactiveSchemaLink.js.map